@@ -1,5 +1,3 @@
-/* global describe, it, xit, expect, require, beforeEach, afterEach */
-
 var runArrayTests = function (it) {
   'use strict';
 
@@ -8,11 +6,16 @@ var runArrayTests = function (it) {
     return typeof Sym === 'function' && typeof sym === 'symbol';
   };
   var functionsHaveNames = (function foo() {}).name === 'foo';
-  var ifFunctionsHaveNamesIt = functionsHaveNames ? it : xit;
-  var ifSymbolIteratorIt = isSymbol(Sym.iterator) ? it : xit;
-  var ifSymbolIteratorAndArrayValuesIt = isSymbol(Sym.iterator) && Array.prototype.values ? it : xit;
-  var ifSymbolUnscopablesIt = isSymbol(Sym.unscopables) ? it : xit;
+  var ifFunctionsHaveNamesIt = functionsHaveNames ? it : it.skip;
+  var ifSymbolIteratorIt = isSymbol(Sym.iterator) ? it : it.skip;
+  var ifSymbolIteratorAndArrayValuesIt = isSymbol(Sym.iterator) && Array.prototype.values ? it : it.skip;
+  var ifSymbolUnscopablesIt = isSymbol(Sym.unscopables) ? it : it.skip;
   var ifShimIt = (typeof process !== 'undefined' && process.env.NO_ES6_SHIM) ? it.skip : it;
+  var ifSupportsDescriptorsIt = Object.getOwnPropertyDescriptor ? it : it.skip;
+
+  var isNegativeZero = function (x) {
+    return (1 / x) < 0;
+  };
 
   describe('Array', function () {
     var list = [5, 10, 15, 20];
@@ -24,7 +27,8 @@ var runArrayTests = function (it) {
 
     describe('@@iterator', function () {
       ifSymbolIteratorIt('uses Symbol.iterator if available', function () {
-        var b = {}, c = {};
+        var b = {};
+        var c = {};
         var a = [b, c];
         var iteratorFn = a[Sym.iterator];
         var iterator = iteratorFn.call(a);
@@ -40,7 +44,7 @@ var runArrayTests = function (it) {
     });
 
     describe('.from()', function () {
-      if (!Array.hasOwnProperty('from')) {
+      if (!Object.prototype.hasOwnProperty.call(Array, 'from')) {
         return it('exists', function () {
           expect(Array).to.have.property('from');
         });
@@ -233,10 +237,12 @@ var runArrayTests = function (it) {
       it('removes holes', function () {
         /*jshint elision: true */
         /* jscs:disable disallowSpaceBeforeComma */
+        /* jscs:disable requireSpaceAfterComma */
         /* eslint-disable no-sparse-arrays */
         var input = [0, , 2];
         var result = Array.from([0, , 2]);
         /* eslint-enable no-sparse-arrays */
+        /* jscs:enable requireSpaceAfterComma */
         /* jscs:enable disallowSpaceBeforeComma */
         /*jshint elision: false */
         expect(1 in input).to.equal(false);
@@ -247,10 +253,30 @@ var runArrayTests = function (it) {
       it('works with this flaky example', function () {
         expect(Array.from([1, NaN, false])).to.eql([1, NaN, false]);
       });
+
+      ifSupportsDescriptorsIt('works when Object.prototype has a throwing setter', function () {
+        // TODO: breaks in Chrome 17, IE 9, Safari 5.1-6
+        var key = 10;
+        /* eslint no-extend-native: 0 */
+        Object.defineProperty(Object.prototype, key, {
+          configurable: true,
+          get: function () {},
+          set: function (v) { throw new EvalError('boom'); }
+        });
+        expect(function () {
+          var arr = [];
+          arr[key] = 42;
+        }).to['throw'](EvalError); // assert thrower
+
+        expect(function () { Array.from({ length: key + 1 }); }).not.to['throw']();
+
+        delete Object.prototype[key];
+        expect(key in Object.prototype).to.equal(false); // assert cleanup
+      });
     });
 
     describe('.of()', function () {
-      if (!Array.hasOwnProperty('of')) {
+      if (!Object.prototype.hasOwnProperty.call(Array, 'of')) {
         return it('exists', function () {
           expect(Array).to.have.property('of');
         });
@@ -303,7 +329,7 @@ var runArrayTests = function (it) {
     });
 
     describe('#copyWithin()', function () {
-      if (!Array.prototype.hasOwnProperty('copyWithin')) {
+      if (!Object.prototype.hasOwnProperty.call(Array.prototype, 'copyWithin')) {
         return it('exists', function () {
           expect(Array.prototype).to.have.property('copyWithin');
         });
@@ -363,10 +389,36 @@ var runArrayTests = function (it) {
         expect(!!unscopables).to.equal(true);
         expect(unscopables.copyWithin).to.equal(true);
       });
+
+      it('should delete the target key if the source key is not present', function () {
+        /* jshint elision: true */
+        /* jscs:disable disallowSpaceBeforeComma */
+        /* jscs:disable requireSpaceAfterComma */
+        /* eslint-disable no-sparse-arrays */
+        expect([, 1, 2].copyWithin(1, 0)).to.eql([, , 1]);
+        /* jshint elision: false */
+        /* jscs:enable requireSpaceAfterComma */
+        /* jscs:enable disallowSpaceBeforeComma */
+        /* eslint-enable no-sparse-arrays */
+      });
+
+      it('should check inherited properties as well', function () {
+        var Parent = function Parent() {};
+        Parent.prototype[0] = 'foo';
+        var sparse = new Parent();
+        sparse[1] = 1;
+        sparse[2] = 2;
+        sparse.length = 3;
+        var result = Array.prototype.copyWithin.call(sparse, 1, 0);
+        expect(result).to.have.property('0');
+        expect(result).not.to.have.ownProperty('0');
+        expect(result).to.have.ownProperty('1');
+        expect(result).to.eql({ 0: 'foo', 1: 'foo', 2: 1, length: 3 });
+      });
     });
 
     describe('#find()', function () {
-      if (!Array.prototype.hasOwnProperty('find')) {
+      if (!Object.prototype.hasOwnProperty.call(Array.prototype, 'find')) {
         return it('exists', function () {
           expect(Array.prototype).to.have.property('find');
         });
@@ -429,9 +481,11 @@ var runArrayTests = function (it) {
       it('should work with a sparse array', function () {
         /*jshint elision: true */
         /* jscs:disable disallowSpaceBeforeComma */
+        /* jscs:disable requireSpaceAfterComma */
         /* eslint-disable no-sparse-arrays */
         var obj = [1, , undefined];
         /* eslint-enable no-sparse-arrays */
+        /* jscs:enable requireSpaceAfterComma */
         /* jscs:enable disallowSpaceBeforeComma */
         /*jshint elision: false */
         expect(1 in obj).to.equal(false);
@@ -463,7 +517,7 @@ var runArrayTests = function (it) {
     });
 
     describe('#findIndex()', function () {
-      if (!Array.prototype.hasOwnProperty('findIndex')) {
+      if (!Object.prototype.hasOwnProperty.call(Array.prototype, 'findIndex')) {
         return it('exists', function () {
           expect(Array.prototype).to.have.property('findIndex');
         });
@@ -526,9 +580,11 @@ var runArrayTests = function (it) {
       it('should work with a sparse array', function () {
         /*jshint elision: true */
         /* jscs:disable disallowSpaceBeforeComma */
+        /* jscs:disable requireSpaceAfterComma */
         /* eslint-disable no-sparse-arrays */
         var obj = [1, , undefined];
         /* eslint-enable no-sparse-arrays */
+        /* jscs:enable requireSpaceAfterComma */
         /* jscs:enable disallowSpaceBeforeComma */
         /*jshint elision: false */
         expect(1 in obj).to.equal(false);
@@ -560,7 +616,7 @@ var runArrayTests = function (it) {
     });
 
     describe('ArrayIterator', function () {
-      if (!Array.prototype.hasOwnProperty('keys')) {
+      if (!Object.prototype.hasOwnProperty.call(Array.prototype, 'keys')) {
         return it('can be tested', function () {
           expect(Array.prototype).to.have.property('keys');
         });
@@ -586,7 +642,7 @@ var runArrayTests = function (it) {
     });
 
     describe('#keys()', function () {
-      if (!Array.prototype.hasOwnProperty('keys')) {
+      if (!Object.prototype.hasOwnProperty.call(Array.prototype, 'keys')) {
         return it('exists', function () {
           expect(Array.prototype).to.have.property('keys');
         });
@@ -657,7 +713,7 @@ var runArrayTests = function (it) {
     });
 
     describe('#values()', function () {
-      if (!Array.prototype.hasOwnProperty('values')) {
+      if (!Object.prototype.hasOwnProperty.call(Array.prototype, 'values')) {
         return it('exists', function () {
           expect(Array.prototype).to.have.property('values');
         });
@@ -728,7 +784,7 @@ var runArrayTests = function (it) {
     });
 
     describe('#entries()', function () {
-      if (!Array.prototype.hasOwnProperty('entries')) {
+      if (!Object.prototype.hasOwnProperty.call(Array.prototype, 'entries')) {
         return it('exists', function () {
           expect(Array.prototype).to.have.property('entries');
         });
@@ -805,7 +861,7 @@ var runArrayTests = function (it) {
     });
 
     describe('#fill()', function () {
-      if (!Array.prototype.hasOwnProperty('fill')) {
+      if (!Object.prototype.hasOwnProperty.call(Array.prototype, 'fill')) {
         return it('exists', function () {
           expect(Array.prototype).to.have.property('fill');
         });
@@ -951,6 +1007,12 @@ var runArrayTests = function (it) {
         expect(reduced).to.equal(accumulator);
       });
     });
+
+    describe('#indexOf()', function () {
+      it('converts second argument from -0 to +0', function () {
+        expect(isNegativeZero([true].indexOf(true, -0))).to.equal(false);
+      });
+    });
   });
 };
 
