@@ -1,9 +1,9 @@
-/* global describe, it, expect, setTimeout, Promise */
-
 var failIfThrows = function (done) {
   'use strict';
 
-  return function (e) { done(e || new Error()); };
+  return function (e) {
+    done(e || new Error());
+  };
 };
 
 describe('Promise.reject', function () {
@@ -29,5 +29,6 @@ describe('Promise.reject', function () {
     expect(function () { Promise.reject.call(42, promise); }).to['throw']();
     expect(function () { Promise.reject.call(false, promise); }).to['throw']();
     expect(function () { Promise.reject.call(true, promise); }).to['throw']();
+    promise.then(null, function () {}); // silence unhandled rejection errors in Chrome
   });
 });
