@@ -1,5 +1,3 @@
-/* global describe, it, xit, expect, require, beforeEach, afterEach */
-
 // Big thanks to V8 folks for test ideas.
 // v8/test/mjsunit/harmony/collections.js
 
@@ -56,7 +54,7 @@ describe('Set', function () {
     return result;
   };
 
-  var prototypePropIsEnumerable = (function () {}).propertyIsEnumerable('prototype');
+  var prototypePropIsEnumerable = Object.prototype.propertyIsEnumerable.call(function () {}, 'prototype');
   var expectNotEnumerable = function (object) {
     if (prototypePropIsEnumerable && typeof object === 'function') {
       expect(Object.keys(object)).to.eql(['prototype']);
@@ -289,7 +287,7 @@ describe('Set', function () {
   });
 
   describe('#keys()', function () {
-    if (!Set.prototype.hasOwnProperty('keys')) {
+    if (!Object.prototype.hasOwnProperty.call(Set.prototype, 'keys')) {
       return it('exists', function () {
         expect(Set.prototype).to.have.property('keys');
       });
@@ -313,7 +311,7 @@ describe('Set', function () {
   });
 
   describe('#values()', function () {
-    if (!Set.prototype.hasOwnProperty('values')) {
+    if (!Object.prototype.hasOwnProperty.call(Set.prototype, 'values')) {
       return it('exists', function () {
         expect(Set.prototype).to.have.property('values');
       });
@@ -332,7 +330,7 @@ describe('Set', function () {
     });
 
     it('throws when called on a non-Set', function () {
-      var expectedMessage = /^(Method )?Set.prototype.values called on incompatible receiver |^values method called on incompatible |^Cannot create a Set value iterator for a non-Set object.$|^Set.prototype.values: 'this' is not a Set object$/;
+      var expectedMessage = /^(Method )?Set.prototype.values called on incompatible receiver |^values method called on incompatible |^Cannot create a Set value iterator for a non-Set object.$|^Set.prototype.values: 'this' is not a Set object$|^std_Set_iterator method called on incompatible \w+$/;
       var nonSets = [true, false, 'abc', NaN, new Map([[1, 2]]), { a: true }, [1], Object('abc'), Object(NaN)];
       nonSets.forEach(function (nonSet) {
         expect(function () { return Set.prototype.values.call(nonSet); }).to['throw'](TypeError, expectedMessage);
@@ -341,7 +339,7 @@ describe('Set', function () {
   });
 
   describe('#entries()', function () {
-    if (!Set.prototype.hasOwnProperty('entries')) {
+    if (!Object.prototype.hasOwnProperty.call(Set.prototype, 'entries')) {
       return it('exists', function () {
         expect(Set.prototype).to.have.property('entries');
       });
@@ -361,7 +359,7 @@ describe('Set', function () {
   });
 
   describe('#has()', function () {
-    if (!Set.prototype.hasOwnProperty('has')) {
+    if (!Object.prototype.hasOwnProperty.call(Set.prototype, 'has')) {
       return it('exists', function () {
         expect(Set.prototype).to.have.property('has');
       });
@@ -414,7 +412,7 @@ describe('Set', function () {
   });
 
   describe('has an iterator that works with Array.from', function () {
-    if (!Array.hasOwnProperty('from')) {
+    if (!Object.prototype.hasOwnProperty.call(Array, 'from')) {
       return it('requires Array.from to exist', function () {
         expect(Array).to.have.property('from');
       });
